@@ -58,8 +58,8 @@ GIRARA_HIDDEN zathura_error_t pdf_page_clear(zathura_page_t* page, void* poppler
  * @return ZATHURA_ERROR_OK when no error occurred, otherwise see
  *    zathura_error_t
  */
-GIRARA_HIDDEN zathura_error_t pdf_document_save_as(zathura_document_t* document,
-    void* poppler_document, const char* path);
+GIRARA_HIDDEN zathura_error_t pdf_document_save_as(zathura_document_t* document, void* poppler_document,
+                                                   const char* path);
 
 /**
  * Generates the index of the document
@@ -70,8 +70,8 @@ GIRARA_HIDDEN zathura_error_t pdf_document_save_as(zathura_document_t* document,
  * @return Tree node object or NULL if an error occurred (e.g.: the document has
  *   no index)
  */
-GIRARA_HIDDEN girara_tree_node_t* pdf_document_index_generate(zathura_document_t* document,
-    void* poppler_document, zathura_error_t* error);
+GIRARA_HIDDEN girara_tree_node_t* pdf_document_index_generate(zathura_document_t* document, void* poppler_document,
+                                                              zathura_error_t* error);
 
 /**
  * Returns a list of attachments included in the zathura document
@@ -81,8 +81,8 @@ GIRARA_HIDDEN girara_tree_node_t* pdf_document_index_generate(zathura_document_t
  *   error occurred
  * @return List of attachments or NULL if an error occurred
  */
-GIRARA_HIDDEN girara_list_t* pdf_document_attachments_get(zathura_document_t* document,
-    void* poppler_document, zathura_error_t* error);
+GIRARA_HIDDEN girara_list_t* pdf_document_attachments_get(zathura_document_t* document, void* poppler_document,
+                                                          zathura_error_t* error);
 
 /**
  * Saves an attachment to a file
@@ -93,8 +93,8 @@ GIRARA_HIDDEN girara_list_t* pdf_document_attachments_get(zathura_document_t* do
  * @return ZATHURA_ERROR_OK when no error occurred, otherwise see
  *    zathura_error_t
  */
-GIRARA_HIDDEN zathura_error_t pdf_document_attachment_save(zathura_document_t*
-    document, void* poppler_document, const char* attachment, const char* filename);
+GIRARA_HIDDEN zathura_error_t pdf_document_attachment_save(zathura_document_t* document, void* poppler_document,
+                                                           const char* attachment, const char* filename);
 
 /**
  * Returns a list of images included on the zathura page
@@ -104,8 +104,7 @@ GIRARA_HIDDEN zathura_error_t pdf_document_attachment_save(zathura_document_t*
  *   error occurred
  * @return List of images
  */
-GIRARA_HIDDEN girara_list_t* pdf_page_images_get(zathura_page_t* page,
-    void* poppler_page, zathura_error_t* error);
+GIRARA_HIDDEN girara_list_t* pdf_page_images_get(zathura_page_t* page, void* poppler_page, zathura_error_t* error);
 
 /**
  * Gets the content of the image in a cairo surface
@@ -116,8 +115,8 @@ GIRARA_HIDDEN girara_list_t* pdf_page_images_get(zathura_page_t* page,
  *   error occurred
  * @return The cairo image surface or NULL if an error occurred
  */
-GIRARA_HIDDEN cairo_surface_t* pdf_page_image_get_cairo(zathura_page_t* page,
-    void* poppler_page, zathura_image_t* image, zathura_error_t* error);
+GIRARA_HIDDEN cairo_surface_t* pdf_page_image_get_cairo(zathura_page_t* page, void* poppler_page,
+                                                        zathura_image_t* image, zathura_error_t* error);
 
 /**
  * Returns a list of document information entries of the document
@@ -127,8 +126,8 @@ GIRARA_HIDDEN cairo_surface_t* pdf_page_image_get_cairo(zathura_page_t* page,
  *   error occurred
  * @return List of information entries or NULL if an error occurred
  */
-GIRARA_HIDDEN girara_list_t* pdf_document_get_information(zathura_document_t* document,
-    void* poppler_document, zathura_error_t* error);
+GIRARA_HIDDEN girara_list_t* pdf_document_get_information(zathura_document_t* document, void* poppler_document,
+                                                          zathura_error_t* error);
 
 /**
  * Searches for a specific text on a page and returns a list of results
@@ -139,8 +138,8 @@ GIRARA_HIDDEN girara_list_t* pdf_document_get_information(zathura_document_t* do
  *   error occurred
  * @return List of search results or NULL if an error occurred
  */
-GIRARA_HIDDEN girara_list_t* pdf_page_search_text(zathura_page_t* page, void*
-    data, const char* text, zathura_error_t* error);
+GIRARA_HIDDEN girara_list_t* pdf_page_search_text(zathura_page_t* page, void* data, const char* text,
+                                                  zathura_error_t* error);
 
 /**
  * Returns a list of internal/external links that are shown on the given page
@@ -150,8 +149,7 @@ GIRARA_HIDDEN girara_list_t* pdf_page_search_text(zathura_page_t* page, void*
  *   error occurred
  * @return List of links or NULL if an error occurred
  */
-GIRARA_HIDDEN girara_list_t* pdf_page_links_get(zathura_page_t* page,
-    void* poppler_page, zathura_error_t* error);
+GIRARA_HIDDEN girara_list_t* pdf_page_links_get(zathura_page_t* page, void* poppler_page, zathura_error_t* error);
 
 /**
  * Returns a list of form fields available on the given page
@@ -161,8 +159,7 @@ GIRARA_HIDDEN girara_list_t* pdf_page_links_get(zathura_page_t* page,
  *   error occurred
  * @return List of form fields or NULL if an error occurred
  */
-GIRARA_HIDDEN girara_list_t* pdf_page_form_fields_get(zathura_page_t* page,
-    void* poppler_page, zathura_error_t* error);
+GIRARA_HIDDEN girara_list_t* pdf_page_form_fields_get(zathura_page_t* page, void* poppler_page, zathura_error_t* error);
 
 /**
  * Get text for selection
@@ -172,11 +169,11 @@ GIRARA_HIDDEN girara_list_t* pdf_page_form_fields_get(zathura_page_t* page,
  * occurred
  * @return The selected text (needs to be deallocated with g_free)
  */
-GIRARA_HIDDEN char* pdf_page_get_text(zathura_page_t* page, void* poppler_page,
-    zathura_rectangle_t rectangle, zathura_error_t* error);
+GIRARA_HIDDEN char* pdf_page_get_text(zathura_page_t* page, void* poppler_page, zathura_rectangle_t rectangle,
+                                      zathura_error_t* error);
 
-GIRARA_HIDDEN girara_list_t*
-pdf_page_get_selection(zathura_page_t* page, void* data, zathura_rectangle_t rectangle, zathura_error_t* error);
+GIRARA_HIDDEN girara_list_t* pdf_page_get_selection(zathura_page_t* page, void* data, zathura_rectangle_t rectangle,
+                                                    zathura_error_t* error);
 
 /**
  * Renders a page onto a cairo object
@@ -187,8 +184,8 @@ pdf_page_get_selection(zathura_page_t* page, void* data, zathura_rectangle_t rec
  * @return ZATHURA_ERROR_OK when no error occurred, otherwise see
  *    zathura_error_t
  */
-GIRARA_HIDDEN zathura_error_t pdf_page_render_cairo(zathura_page_t* page, void*
-    poppler_page, cairo_t* cairo, bool printing);
+GIRARA_HIDDEN zathura_error_t pdf_page_render_cairo(zathura_page_t* page, void* poppler_page, cairo_t* cairo,
+                                                    bool printing);
 
 /**
  * Get the page label
@@ -199,8 +196,7 @@ GIRARA_HIDDEN zathura_error_t pdf_page_render_cairo(zathura_page_t* page, void*
  * @return ZATHURA_ERROR_OK when no error occurred, otherwise see
  *    zathura_error_t
  */
-GIRARA_HIDDEN zathura_error_t pdf_page_get_label(zathura_page_t* page,
-    void* data, char** label);
+GIRARA_HIDDEN zathura_error_t pdf_page_get_label(zathura_page_t* page, void* data, char** label);
 
 /**
  * Get signatures
